@@ -45,5 +45,16 @@ This package mimics the L<APR::Pool> object obtained via $r->pool in a normal mo
 
 Causes the subref to be executed with C<\@args> at the end of the current request.
 
+=head1 BUGS
+
+It's possible that some bugs have found their way into this release.
+
+Use RT L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=ASP4> to submit bug reports.
+
+=head1 HOMEPAGE
+
+Please visit the ASP4 homepage at L<http://0x31337.org/code/> to see examples
+of ASP4 in action.
+
 =cut
 
